Amino Acids
===========

The amino acids module provides lookups for standard and non-standard amino acids.


.. automodule:: tacular.amino_acids
   :members:
   :undoc-members:
   :show-inheritance:
